@@ -163,7 +163,8 @@ static const AtkRoleItem role_items [] =
   { ATK_ROLE_HEADING, N_("heading")},
   { ATK_ROLE_PAGE, N_("page")},
   { ATK_ROLE_SECTION, N_("section")},
-  { ATK_ROLE_REDUNDANT_OBJECT, N_("redundant object")}
+  { ATK_ROLE_REDUNDANT_OBJECT, N_("redundant object")},
+  { ATK_ROLE_FORM, N_("form")}
 };
 
 static void            atk_object_class_init        (AtkObjectClass  *klass);
@@ -247,7 +248,7 @@ get_atk_locale_dir (void)
 
   if (!atk_localedir)
     {
-      gchar temp;
+      gchar *temp;
 
       temp = g_win32_get_package_installation_subdirectory
         (GETTEXT_PACKAGE, dll_name, "lib\\locale");
@@ -737,9 +738,9 @@ atk_object_get_role (AtkObject *accessible)
  *
  * Gets the layer of the accessible.
  *
- * Returns: an #AtkLayer which is the layer of the accessible
+ * Deprecated: Use atk_component_get_layer instead.
  *
- * @Deprecated: Use atk_component_get_layer instead.
+ * Returns: an #AtkLayer which is the layer of the accessible
  **/
 AtkLayer
 atk_object_get_layer (AtkObject *accessible) 
@@ -762,11 +763,12 @@ atk_object_get_layer (AtkObject *accessible)
  * Gets the zorder of the accessible. The value G_MININT will be returned 
  * if the layer of the accessible is not ATK_LAYER_MDI.
  *
+ * Deprecated: Use atk_component_get_mdi_zorder instead.
+ *
  * Returns: a gint which is the zorder of the accessible, i.e. the depth at 
  * which the component is shown in relation to other components in the same 
  * container.
  *
- * @Deprecated: Use atk_component_get_mdi_zorder instead.
  **/
 gint
 atk_object_get_mdi_zorder (AtkObject *accessible) 
@@ -1008,17 +1010,17 @@ atk_object_notify_state_change (AtkObject *accessible,
  * Returns: a reference to an object's #AtkObject implementation
  */
 AtkObject *
-atk_implementor_ref_accessible (AtkImplementor *object)
+atk_implementor_ref_accessible (AtkImplementor *implementor)
 {
   AtkImplementorIface *iface;
   AtkObject           *accessible = NULL;
 
-  g_return_val_if_fail (ATK_IS_IMPLEMENTOR (object), NULL);
+  g_return_val_if_fail (ATK_IS_IMPLEMENTOR (implementor), NULL);
 
-  iface = ATK_IMPLEMENTOR_GET_IFACE (object);
+  iface = ATK_IMPLEMENTOR_GET_IFACE (implementor);
 
   if (iface != NULL) 
-    accessible =  iface->ref_accessible (object);
+    accessible =  iface->ref_accessible (implementor);
 
   g_return_val_if_fail ((accessible != NULL), NULL);
 
@@ -1027,11 +1029,18 @@ atk_implementor_ref_accessible (AtkImplementor *object)
 
     	
 /**
+ * atk_object_get_attributes:
+ * @accessible: An #AtkObject.
+ *
  * Get a list of properties applied to this object as a whole, as an #AtkAttributeSet consisting of 
  * name-value pairs. As such these attributes may be considered weakly-typed properties or annotations, 
  * as distinct from strongly-typed object data available via other get/set methods.
  * Not all objects have explicit "name-value pair" #AtkAttributeSet properties.
- * @Since ATK 1.12
+ *
+ * Since: ATK 1.12
+ *
+ * Returns: an #AtkAttributeSet consisting of all explicit properties/annotations applied to 
+ * the object, or an empty set if the object has no name-value pair attributes assigned to it.
  */
 AtkAttributeSet *
 atk_object_get_attributes (AtkObject                  *accessible)
